/*
 * Copyright (c) 2010 by Intevation GmbH
 *
 * This program is free software under the LGPL (>=v2.1)
 * Read the file LGPL.txt coming with the software for details
 * or visit http://www.gnu.org/licenses/ if it does not exist.
 */

package de.intevation.gnv.artifacts;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.ArtifactFactory;
import de.intevation.artifacts.CallContext;

import java.io.FileOutputStream;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;

/**
 * @author <a href="mailto:tim.englich@intevation.de">Tim Englich</a>
 *
 */
public class TimeSeriesPointTimeSeriesTestCase extends GNVArtifactsTestCaseBase {


    /**
     * the logger, used to log exceptions and additonaly information
     */
    private static Logger log = Logger.getLogger(TimeSeriesPointTimeSeriesTestCase.class);

    /**
     * Constructor
     */
    public TimeSeriesPointTimeSeriesTestCase() {
    }

    /**
     * Constructor
     * @param name
     */
    public TimeSeriesPointTimeSeriesTestCase(String name) {
        super(name);
    }

    /**
     * @see de.intevation.gnv.artifacts.GNVArtifactsTestCaseBase#testArtifact()
     */
    @Override
    public void testArtifact() {
        log.debug("GNVArtifactsTestCase.testTimeSeriesArtifact");
        try {
            String artefactName = "fis_marnet";
            ArtifactFactory artifactFactory = this
                    .getArtifactFactory(artefactName);
            assertNotNull(artifactFactory);
            log.debug("TimeSeries-ArtifactFactory is available");

            Artifact artifact = createArtifact(artifactFactory);

            CallContext cc = createCallContext(artifactFactory);

            // Erster Schritt

            Document describeDocument = this.readDocument("src/test/ressources/timeseries/timeseries_describe.xml");

            int steps = 6;

            for (int i = 1; i <= steps; i++){

                this.doNextStep(
                            artifact,
                            cc,
                            "src/test/ressources/timeseries/" +
                            "timeseries_step_0"+i+"_feed.xml",
                            "src/test/ressources/timeseries/" +
                            "timeseries_step_0"+i+"_advance.xml",
                            describeDocument);
            }

            Document outputData = artifact.describe(describeDocument,cc);
            FileOutputStream fos = null;
            FileOutputStream fos2 = null;
            FileOutputStream fos3 = null;
            FileOutputStream fos4 = null;
            try {
                fos = new FileOutputStream("src/test/results/timeseries"
                                           + System.currentTimeMillis()
                                           + ".png");
                fos2 = new FileOutputStream("src/test/results/timeseries"
                                            + System.currentTimeMillis()
                                            + ".xml");
                fos3 = new FileOutputStream("src/test/results/timeseries"
                                            + System.currentTimeMillis()
                                            + ".csv");
                fos4 = new FileOutputStream("src/test/results/timeseries"
                        + System.currentTimeMillis()
                        + ".odv");

                artifact.out(this
                             .readDocument("src/test/ressources/timeseries/timeseries_step_06_out_chart.xml"),
                                           fos, cc);
                artifact.out(this
                        .readDocument("src/test/ressources/timeseries/timeseries_step_06_out_statistics.xml"),
                                      fos2, cc);
                artifact.out(this
                        .readDocument("src/test/ressources/timeseries/timeseries_step_06_out_csv.xml"),
                                      fos3, cc);
                artifact.out(this
                        .readDocument("src/test/ressources/timeseries/timeseries_step_06_out_odv.xml"),
                                      fos4, cc);
            } catch (Exception e) {
                log.error(e, e);
                fail();
            } finally {
                try {
                    fos.flush();
                    fos.close();
                } catch (Exception e) {
                    log.error(e, e);
                }
            }
        } catch (Exception e) {
            log.error(e, e);
            fail();
        }
    }

}
